searchData={"items":[{"type":"module","title":"Ecto.Adapters.SQLite3","doc":"Adapter module for SQLite3.\n\nIt uses `Exqlite` for communicating to the database.","ref":"Ecto.Adapters.SQLite3.html"},{"type":"module","title":"Options - Ecto.Adapters.SQLite3","doc":"The adapter supports a superset of the options provided by the\nunderlying `Exqlite` driver.","ref":"Ecto.Adapters.SQLite3.html#module-options"},{"type":"module","title":"Provided options - Ecto.Adapters.SQLite3","doc":"* `:database` - The path to the database. In memory is allowed. You can use\n    `:memory` or `\":memory:\"` to designate that.\n  * `:default_transaction_mode` - one of `:deferred` (default), `:immediate`, or\n    `:exclusive`. If a mode is not specified in a call to `Repo.transaction/2`, this\n    will be the default transaction mode.\n  * `:journal_mode` - Sets the journal mode for the sqlite connection. Can be one of\n    the following `:delete`, `:truncate`, `:persist`, `:memory`, `:wal`, or `:off`.\n    Defaults to `:wal`.\n  * `:temp_store` - Sets the storage used for temporary tables. Default is `:default`.\n    Allowed values are `:default`, `:file`, `:memory`.\n  * `:synchronous` - Can be `:extra`, `:full`, `:normal`, or `:off`. Defaults to `:normal`.\n  * `:foreign_keys` - Sets if foreign key checks should be enforced or not. Can be\n    `:on` or `:off`. Default is `:on`.\n  * `:cache_size` - Sets the cache size to be used for the connection. This is an odd\n    setting as a positive value is the number of pages in memory to use and a negative\n    value is the size in kilobytes to use. Default is `-64000`.\n  * `:cache_spill` - The cache_spill pragma enables or disables the ability of the\n    pager to spill dirty cache pages to the database file in the middle of a\n    transaction. By default it is `:on`, and for most applications, it should remain\n    so.\n  * `:case_sensitive_like` - whether LIKE is case-sensitive or not. Can be\n    `:off` or `:on`. Defaults to `:off`.\n  * `:auto_vacuum` - Defaults to `:none`. Can be `:none`, `:full` or `:incremental`.\n    Depending on the database size, `:incremental` may be beneficial.\n  * `:locking_mode` - Defaults to `:normal`. Allowed values are `:normal` or\n    `:exclusive`. See [sqlite documentation][1] for more information.\n  * `:secure_delete` - Defaults to `:off`. Can be `:off` or `:on`. If `:on`, it will\n    cause SQLite3 to overwrite records that were deleted with zeros.\n  * `:wal_auto_check_point` - Sets the write-ahead log auto-checkpoint interval.\n    Default is `1000`. Setting the auto-checkpoint size to zero or a negative value\n    turns auto-checkpointing off.\n  * `:busy_timeout` - Sets the busy timeout in milliseconds for a connection.\n    Default is `2000`.\n  * `:pool_size` - the size of the connection pool. Defaults to `5`.\n  * `:binary_id_type` - Defaults to `:string`. Determines how binary IDs are stored in\n    the database and the type of `:binary_id` columns. See the\n    [section on binary ID types](#module-binary-id-types) for more details.\n  * `:uuid_type` - Defaults to `:string`. Determines the type of `:uuid` columns.\n    Possible values and column types are the same as for\n    [binary IDs](#module-binary-id-types).\n  * `:datetime_type` - Defaults to `:iso8601`. Determines how datetime fields are\n    stored in the database. The allowed values are `:iso8601` and `:text_datetime`.\n    `:iso8601` corresponds to a string of the form `YYYY-MM-DDThh:mm:ss` and\n    `:text_datetime` corresponds to a string of the form `YYYY-MM-DD hh:mm:ss`\n  * `:load_extensions` - list of paths identifying extensions to load. Defaults to `[]`.\n     The provided list will be merged with the global extensions list, set on\n     `:exqlite, :load_extensions`. Be aware that the path should handle pointing to a\n     library compiled for the current architecture. See `Exqlite.Connection.connect/1`\n     for more.\n\nFor more information about the options above, see [sqlite documentation][1]","ref":"Ecto.Adapters.SQLite3.html#module-provided-options"},{"type":"module","title":"Differences between SQLite and Ecto SQLite defaults - Ecto.Adapters.SQLite3","doc":"For the most part, the defaults we provide above match the defaults that SQLite usually\nships with. However, SQLite has conservative defaults due to its need to be strictly\nbackwards compatible, so some of them do not necessarily match \"best practices\". Below\nare the defaults we provide above that differ from the normal SQLite defaults, along\nwith rationale.\n\n  * `:journal_mode` - we use `:wal`, as it is vastly superior\n    for concurrent access. SQLite usually defaults to `:delete`.\n    See [SQLite documentation][2] for more info.\n  * `:temp_store` - we use `:memory`, which increases performance a bit.\n    SQLite usually defaults to `:file`.\n  * `:foreign_keys` - we set it to `:on`, for better relational guarantees.\n    This is also the default of the underlying `Exqlite` driver.\n    SQLite usually defaults to `:off` for backwards compat.\n  * `:busy_timeout` - we set it to `2000`, to better enable concurrent access.\n    This is also the default of `Exqlite`. SQLite usually defaults to `0`.\n  * `:cache_size` - we set it to `-64000`, to speed up access of data.\n    SQLite usually defaults to `-2000`.\n\nThese defaults can of course be overridden, as noted above, to suit other needs.\n\n[1]: https://www.sqlite.org/pragma.html\n[2]: https://sqlite.org/wal.html","ref":"Ecto.Adapters.SQLite3.html#module-differences-between-sqlite-and-ecto-sqlite-defaults"},{"type":"module","title":"Binary ID types - Ecto.Adapters.SQLite3","doc":"The `:binary_id_type` configuration option allows configuring how `:binary_id` fields\nare stored in the database as well as the type of the column in which these IDs will\nbe stored. The possible values are:\n\n* `:string` - IDs are stored as strings, and the type of the column is `TEXT`. This is\n  the default.\n* `:binary` - IDs are stored in their raw binary form, and the type of the column is `BLOB`.\n\nThe main differences between the two formats are as follows:\n* When stored as binary, UUIDs require much less space in the database. IDs stored as\n  strings require 36 bytes each, while IDs stored as binary only require 16 bytes.\n* Because SQLite does not have a dedicated UUID type, most clients cannot represent\n  UUIDs stored as binary in a human readable format. Therefore, IDs stored as strings\n  may be easier to work with if manual manipulation is required.","ref":"Ecto.Adapters.SQLite3.html#module-binary-id-types"},{"type":"module","title":"Limitations and caveats - Ecto.Adapters.SQLite3","doc":"There are some limitations when using Ecto with SQLite that one needs\nto be aware of. The ones listed below are specific to Ecto usage, but it\nis encouraged to also view the guidance on [when to use SQLite][4] provided\nby the SQLite documentation, as well.","ref":"Ecto.Adapters.SQLite3.html#module-limitations-and-caveats"},{"type":"module","title":"In memory robustness - Ecto.Adapters.SQLite3","doc":"When using the Ecto SQLite3 adapter with the database set to `:memory` it\nis possible that a crash in a process performing a query in the Repo will\ncause the database to be destroyed. This makes the `:memory` function\nunsuitable when it is expected to survive potential process crashes (for\nexample a crash in a Phoenix request)","ref":"Ecto.Adapters.SQLite3.html#module-in-memory-robustness"},{"type":"module","title":"Async Sandbox testing - Ecto.Adapters.SQLite3","doc":"The Ecto SQLite3 adapter does not support async tests when used with\n`Ecto.Adapters.SQL.Sandbox`. This is due to SQLite only allowing up one write\ntransaction at a time, which often does not work with the Sandbox approach of wrapping\neach test in a transaction.","ref":"Ecto.Adapters.SQLite3.html#module-async-sandbox-testing"},{"type":"module","title":"LIKE match on BLOB columns - Ecto.Adapters.SQLite3","doc":"We have the `SQLITE_LIKE_DOESNT_MATCH_BLOBS` compile-time definition option set to true,\nas [recommended by SQLite][3]. This means you cannot do `LIKE` queries on `BLOB` columns.","ref":"Ecto.Adapters.SQLite3.html#module-like-match-on-blob-columns"},{"type":"module","title":"Case sensitivity - Ecto.Adapters.SQLite3","doc":"Case sensitivity for `LIKE` is off by default, and controlled by the `:case_sensitive_like`\noption outlined above.\n\nHowever, for equality comparison, case sensitivity is always _on_.\nIf you want to make a column not be case sensitive, for email storage for example, you\ncan make it case insensitive by using the [`COLLATE NOCASE`][6] option in SQLite. This\nis configured via the `:collate` option.\n\nSo instead of:\n\n    add :email, :string\n\nYou would do:\n\n    add :email, :string, collate: :nocase","ref":"Ecto.Adapters.SQLite3.html#module-case-sensitivity"},{"type":"module","title":"Check constraints - Ecto.Adapters.SQLite3","doc":"SQLite3 supports specifying check constraints on the table or on the column definition.\nWe currently only support adding a check constraint via a column definition, since the\ntable definition approach only works at table-creation time and cannot be added at\ntable-alter time. You can see more information in the SQLite3\n[CREATE TABLE documentation](https://sqlite.org/lang_createtable.html).\n\nBecause of this, you cannot add a constraint via the normal `Ecto.Migration.constraint/3`\nmethod, as that operates via `ALTER TABLE ADD CONSTRAINT`, and this type of `ALTER TABLE`\noperation SQLite3 does not support. You can however get the full functionality by\nadding a constraint at the column level, specifying the name and expression. Per the\nSQLite3 documentation, there is no _functional_ difference between a column or table\nconstraint.\n\nThus, adding a check constraint for a new column is as simple as:\n\n    add :email, :string, check: %{name: \"test_constraint\", expr: \"email != 'test@example.com'\"}","ref":"Ecto.Adapters.SQLite3.html#module-check-constraints"},{"type":"module","title":"Handling foreign key constraints in changesets - Ecto.Adapters.SQLite3","doc":"Unfortunately, unlike other databases, SQLite3 does not provide the precise name of\nthe constraint violated, but only the columns within that constraint (if it provides\nany information at all). Because of this, changeset functions like\n`Ecto.Changeset.foreign_key_constraint/3` may not work at all.\n\nThis is because the above functions depend on the Ecto Adapter returning the name of\nthe violated constraint, which you annotate in your changeset so that Ecto can convert\nthe constraint violation into the correct updated changeset when the constraint is hit\nduring a `c:Ecto.Repo.update/2` or `c:Ecto.Repo.insert/2` operation. Since we cannot\nget the name of the violated constraint back from SQLite3 at `INSERT` or `UPDATE`\ntime, there is no way to effectively use these changeset functions. This is a SQLite3\nlimitation.\n\nSee [this GitHub issue](https://github.com/elixir-sqlite/ecto_sqlite3/issues/42) for\nmore details.","ref":"Ecto.Adapters.SQLite3.html#module-handling-foreign-key-constraints-in-changesets"},{"type":"module","title":"Schemaless queries - Ecto.Adapters.SQLite3","doc":"Using [schemaless Ecto queries][7] will not work well with SQLite. This is because\nthe Ecto SQLite adapter relies heavily on the schema to support a rich array of Elixir\ntypes, despite the fact SQLite only has [five storage classes][5]. The query will still\nwork and return data, but you will need to do this mapping on your own.","ref":"Ecto.Adapters.SQLite3.html#module-schemaless-queries"},{"type":"module","title":"Transaction mode - Ecto.Adapters.SQLite3","doc":"By default, [SQLite transactions][8] run in `DEFERRED` mode. However, in \nweb applications with a balanced load of reads and writes, using  `IMMEDIATE` \nmode may yield better performance.\n\nHere are several ways to specify a different transaction mode:\n\n**Pass `mode: :immediate` to `Repo.transaction/2`:** Use this approach to set \nthe transaction mode for individual transactions.\n\n    Multi.new()\n    |> Multi.run(:example, fn _repo, _changes_so_far ->\n      # ... do some work ...\n    end)\n    |> Repo.transaction(mode: :immediate)\n\n**Define custom transaction functions:** Create wrappers, such as \n`Repo.immediate_transaction/2` or `Repo.deferred_transaction/2`, to easily \napply different modes where needed.\n\n    defmodule MyApp.Repo do\n      def immediate_transaction(fun_or_multi) do\n        transaction(fun_or_multi, mode: :immediate)\n      end\n\n      def deferred_transaction(fun_or_multi) do\n        transaction(fun_or_multi, mode: :deferred)\n      end\n    end\n\n**Set a global default:** Configure `:default_transaction_mode` to apply a \npreferred mode for all transactions, unless explicitly passed a different\n`:mode` to `Repo.transaction/2`.\n\n    config :my_app, MyApp.Repo,\n      database: \"path/to/my/database.db\",\n      default_transaction_mode: :immediate\n\n[3]: https://www.sqlite.org/compile.html\n[4]: https://www.sqlite.org/whentouse.html\n[5]: https://www.sqlite.org/datatype3.html\n[6]: https://www.sqlite.org/datatype3.html#collating_sequences\n[7]: https://hexdocs.pm/ecto/schemaless-queries.html\n[8]: https://www.sqlite.org/lang_transaction.html#deferred_immediate_and_exclusive_transactions","ref":"Ecto.Adapters.SQLite3.html#module-transaction-mode"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}